==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/tcr/v20190924/models/NamespaceIsExistsResp.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcr.v20190924.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class NamespaceIsExistsResp extends AbstractModel{

    /**
    * 命名空间是否存在
    */
    @SerializedName("IsExist")
    @Expose
    private Boolean IsExist;

    /**
    * 是否为保留命名空间
    */
    @SerializedName("IsPreserved")
    @Expose
    private Boolean IsPreserved;

    /**
     * Get 命名空间是否存在 
     * @return IsExist 命名空间是否存在
     */
    public Boolean getIsExist() {
        return this.IsExist;
    }

    /**
     * Set 命名空间是否存在
     * @param IsExist 命名空间是否存在
     */
    public void setIsExist(Boolean IsExist) {
        this.IsExist = IsExist;
    }

    /**
     * Get 是否为保留命名空间 
     * @return IsPreserved 是否为保留命名空间
     */
    public Boolean getIsPreserved() {
        return this.IsPreserved;
    }

    /**
     * Set 是否为保留命名空间
     * @param IsPreserved 是否为保留命名空间
     */
    public void setIsPreserved(Boolean IsPreserved) {
        this.IsPreserved = IsPreserved;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "IsExist", this.IsExist);
        this.setParamSimple(map, prefix + "IsPreserved", this.IsPreserved);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/tcr/v20190924/models/NamespaceIsExistsResp.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcr.v20190924.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class NamespaceIsExistsResp extends AbstractModel{

    /**
    * 命名空间是否存在
    */
    @SerializedName("IsExist")
    @Expose
    private Boolean IsExist;

    /**
    * 是否为保留命名空间
    */
    @SerializedName("IsPreserved")
    @Expose
    private Boolean IsPreserved;

    /**
     * Get 命名空间是否存在 
     * @return IsExist 命名空间是否存在
     */
    public Boolean getIsExist() {
        return this.IsExist;
    }

    /**
     * Set 命名空间是否存在
     * @param IsExist 命名空间是否存在
     */
    public void setIsExist(Boolean IsExist) {
        this.IsExist = IsExist;
    }

    /**
     * Get 是否为保留命名空间 
     * @return IsPreserved 是否为保留命名空间
     */
    public Boolean getIsPreserved() {
        return this.IsPreserved;
    }

    /**
     * Set 是否为保留命名空间
     * @param IsPreserved 是否为保留命名空间
     */
    public void setIsPreserved(Boolean IsPreserved) {
        this.IsPreserved = IsPreserved;
    }

    public NamespaceIsExistsResp() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public NamespaceIsExistsResp(NamespaceIsExistsResp source) {
        if (source.IsExist != null) {
            this.IsExist = new Boolean(source.IsExist);
        }
        if (source.IsPreserved != null) {
            this.IsPreserved = new Boolean(source.IsPreserved);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "IsExist", this.IsExist);
        this.setParamSimple(map, prefix + "IsPreserved", this.IsPreserved);

    }
}
